==> ruby-freedb-0.3.tgz: lib/ruby/site_ruby/1.6/freedb_misc.rb <==
# $Id: freedb_misc.rb,v 1.9 2002/04/07 13:40:20 moumar Exp $ 
class FreedbError < StandardError ; end

class Freedb
  VERSION = "0.3"
  PROTO_LEVEL = 1
  attr_reader :results, :artist, :title, :tracks, :discid
  
  def initialize(param = "/dev/cdrom", is_discid = false)
    @discid = ( is_discid ? param : get_cdrom(param) )
    @tracks = Array.new()
    @hello_str="#{ENV["USER"]} #{`hostname`.strip} ruby-freedb #{VERSION}"
  end

  def fetch_net(server = "freedb.org", port = 8880)
    @handler = FetchNet.new(server, port)
    _fetch
  end
  alias fetch fetch_net

  def fetch_cgi(server = "www.freedb.org", port = 80, proxy = nil, proxy_port = nil, address = "/~cddb/cddb.cgi")
    @handler = FetchCGI.new(server, port, proxy, proxy_port, address)
    _fetch
  end

  def get_result(index)
    line = /\w+ \w+/.match(@results[index])[0]
    @handler.send_cmd("read", line)
    lines = getmultiline(@handler)
    lines.each { |line|
      case line
        when /^DTITLE=/
	  md = /DTITLE=(.*) \/ (.*)/.match(line)
	  if md.nil? #the DTITLE field is wrong.Should we throw an exception?
	    @artist = ""
	    @title = /DTITLE=(.*)/.match(line)[1]
	  else
	    @artist = md[1]
	    @title = md[2]
	  end
	when /^TTITLE\d+=/
	  md = /^TTITLE\d+=(.*)/.match(line)
	  @tracks << md[1]
	#when /^TTITLE\d+=/
      end
    }
  end
  
  def close
    @handler.close
  end

private

  def _fetch
    @handler.gets #banner
    @handler.send_cmd("hello", @hello_str)
    @handler.gets #welcome
    @handler.send_cmd("query", @discid)
    resp = @handler.gets
    @results = []
    case resp
      when /^200/ #single result
	md = /^200 (.*)/.match(resp)
	@results << md[1]
      when /^211/
	@results = getmultiline(@handler)
    end
  end
  
  def getmultiline(h)
    arr = []
    until (l = h.gets) =~ /^\./
      arr << l.strip
    end
    return arr
  end

  class FetchCGI

    def initialize(server, port, proxy, proxy_port, url)
      require "net/http"
      @session = Net::HTTP.new(server, port, proxy, proxy_port)
      @url = url
    end

    def send_cmd(cmd, args)
      if cmd == "hello" 
        @hello_str = "hello=" + parse_str(args)
      else
        request = "?cmd=cddb+#{cmd}+#{parse_str(args)}&#{@hello_str}&proto=#{PROTO_LEVEL}"
        resp, data = @session.get(@url + request)
	raise(FreedbError, "Bad HTTP response: #{resp.code} #{resp.message} while querying server") unless resp.code == "200"
	@res = data.split("\n")
      end
    end

    def gets
      return (@res.nil? ? "" : @res.shift)
    end
 
    def close
      #@session.finish
    end

    def parse_str(str)
      return str.gsub(" ", "+")
    end
  end

  class FetchNet

    def initialize(server, port)
      require "socket"
      @socket = TCPSocket.new(server, port)
    end

    def send_cmd(cmd, args)
      @socket.puts("cddb #{cmd} #{args}")
    end
    
    def gets
      return @socket.gets
    end

    def close
      @socket.close      
    end 
  end
=begin
  class FetchDisk
    def initialize(dir)
      require "find"
      raise(FreedbError, "#{dir} is not a directory") if not dir.stat.directory?
      @dir = dir
    end

    def send_cmd(cmd, args)
      case cmd
        when "hello"
        when "query"
	  match = []
	  Find.find(@dir) { |f|
	    if md = /#{f}\/(\s+)\/#{args}/.match(f)
	      match << md[1] 
	    end
	  }
	  if match.size == 1
            @res[0] = "200"
	  elsif match.size > 1
	    @res[0] = "202"
	  else
	    @res[0] = "211"
	  end
        when "read"
	  categ, id = cmd.split(" ")
	  File.open(@dir + File::SEPARATOR + categ + File::SEPARATOR + id, "r") { |f|
	    @res = f.readlines
	  }
      end
    end

    def gets
      return @res.shift
    end

    def close
    end
  end
=end
end

==> ruby-freedb-0.3.1.tgz: lib/ruby/site_ruby/1.6/freedb_misc.rb <==
# $Id: freedb_misc.rb,v 1.10 2002/08/30 17:45:36 moumar Exp $ 
class FreedbError < StandardError ; end

class Freedb
  VERSION = "0.3.1"
  PROTO_LEVEL = 1
  attr_reader :results, :genre, :artist, :title, :tracks, :discid
  
  def initialize(param = "/dev/cdrom", is_discid = false)
    @discid = ( is_discid ? param : get_cdrom(param) )
    @tracks = Array.new()
    @hello_str="#{ENV['USER']} #{`hostname`.strip} ruby-freedb #{VERSION}"
  end

  def fetch_net(server = "freedb.org", port = 8880)
    @handler = FetchNet.new(server, port)
    _fetch
  end
  alias fetch fetch_net

  def fetch_cgi(server = "www.freedb.org", port = 80, proxy = nil, proxy_port = nil, address = "/~cddb/cddb.cgi")
    @handler = FetchCGI.new(server, port, proxy, proxy_port, address)
    _fetch
  end

  def get_result(index)
    line = /\w+ \w+/.match(@results[index])[0]
    @handler.send_cmd("read", line)
    lines = getmultiline(@handler)
    lines.each { |line|
      case line
	when /^210 (\S+)/
	  @genre = $1
        when /^DTITLE=/
	  md = /DTITLE=(.*) \/ (.*)/.match(line)
	  if md.nil? #the DTITLE field is wrong.Should we throw an exception?
	    @artist = ""
	    @title = /DTITLE=(.*)/.match(line)[1]
	  else
	    @artist = md[1]
	    @title = md[2]
	  end
	when /^TTITLE\d+=/
	  md = /^TTITLE\d+=(.*)/.match(line)
	  @tracks << md[1]
	#when /^TTITLE\d+=/
      end
    }
  end
  
  def close
    @handler.close
  end

private

  def _fetch
    @handler.gets #banner
    @handler.send_cmd("hello", @hello_str)
    @handler.gets #welcome
    @handler.send_cmd("query", @discid)
    resp = @handler.gets
    @results = []
    case resp
      when /^200/ #single result
	md = /^200 (.*)/.match(resp)
	@results << md[1]
      when /^211/
	@results = getmultiline(@handler)
    end
  end
  
  def getmultiline(h)
    arr = []
    until (l = h.gets) =~ /^\./
      arr << l.strip
    end
    return arr
  end

  class FetchCGI

    def initialize(server, port, proxy, proxy_port, url)
      require "net/http"
      @session = Net::HTTP.new(server, port, proxy, proxy_port)
      @url = url
    end

    def send_cmd(cmd, args)
      if cmd == "hello" 
        @hello_str = "hello=" + parse_str(args)
      else
        request = "?cmd=cddb+#{cmd}+#{parse_str(args)}&#{@hello_str}&proto=#{PROTO_LEVEL}"
        resp, data = @session.get(@url + request)
	raise(FreedbError, "Bad HTTP response: #{resp.code} #{resp.message} while querying server") unless resp.code == "200"
	@res = data.split("\n")
      end
    end

    def gets
      return (@res.nil? ? "" : @res.shift)
    end
 
    def close
      #@session.finish
    end

    def parse_str(str)
      return str.gsub(" ", "+")
    end
  end

  class FetchNet

    def initialize(server, port)
      require "socket"
      @socket = TCPSocket.new(server, port)
    end

    def send_cmd(cmd, args)
      @socket.puts("cddb #{cmd} #{args}")
    end
    
    def gets
      return @socket.gets
    end

    def close
      @socket.close      
    end 
  end
=begin
  class FetchDisk
    def initialize(dir)
      require "find"
      raise(FreedbError, "#{dir} is not a directory") if not dir.stat.directory?
      @dir = dir
    end

    def send_cmd(cmd, args)
      case cmd
        when "hello"
        when "query"
	  match = []
	  Find.find(@dir) { |f|
	    if md = /#{f}\/(\s+)\/#{args}/.match(f)
	      match << md[1] 
	    end
	  }
	  if match.size == 1
            @res[0] = "200"
	  elsif match.size > 1
	    @res[0] = "202"
	  else
	    @res[0] = "211"
	  end
        when "read"
	  categ, id = cmd.split(" ")
	  File.open(@dir + File::SEPARATOR + categ + File::SEPARATOR + id, "r") { |f|
	    @res = f.readlines
	  }
      end
    end

    def gets
      return @res.shift
    end

    def close
    end
  end
=end
end
